=============
Release notes
=============

0.3.0 (2025-09-02)
==================

| Extended easy intersphinx configuration to:
| `jinja <https://jinja.palletsprojects.com/en/latest/>`_
| `lxml <https://lxml.de/apidoc/>`_


0.2.0 (2025-06-16)
==================

| Extended easy intersphinx configuration to:
| `dateparser <https://dateparser.readthedocs.io/en/latest/>`_
| `form2request <https://form2request.readthedocs.io/en/latest/>`_
| `formasaurus <https://formasaurus.readthedocs.io/en/latest/>`_
| `python-scrapinghub <https://python-scrapinghub.readthedocs.io/en/latest/>`_
| `scrapy-spider-metadata <https://scrapy-spider-metadata.readthedocs.io/en/latest/>`_
| `scrapy-zyte-api <https://scrapy-zyte-api.readthedocs.io/en/latest/>`_
| `scrapy-zyte-smartproxy <https://scrapy-zyte-smartproxy.readthedocs.io/en/latest/>`_
| `scrapyd <https://scrapyd.readthedocs.io/en/latest/>`_
| `shub <https://shub.readthedocs.io/en/latest/>`_
| `shub-image <https://shub-image.readthedocs.io/en/latest/>`_
| `spidermon <https://spidermon.readthedocs.io/en/latest/>`_
| `url-matcher <https://url-matcher.readthedocs.io/en/stable/>`_
| `zyte-parsers <https://zyte-parsers.readthedocs.io/en/latest/>`_


0.1.0 (2025-06-14)
==================

Initial release.
